last_load_error

Function last_load_error 

pub fn last_load_error() -> Option<&'static str>
Returns a description of why the Botan library could not be loaded

This is only ever Some when the dynamic-loading feature is enabled and loading the Botan shared library failed; in the linked build modes it always returns None.